@@ -11,7 +11,7 @@
 #include <kdev-pg-list.h>
 
 
-# 45 "/build/kdevelop-php/src/kdev-php-23.04.3/parser/php.g" 1
+# 45 "/build/kdevelop-php/src/kdev-php-23.08.2/parser/php.g" 1
 
 
 #include <QtCore/QRegularExpression>
@@ -26,7 +26,7 @@ namespace Php
 {
 
 
-# 79 "/build/kdevelop-php/src/kdev-php-23.04.3/parser/php.g" 1
+# 79 "/build/kdevelop-php/src/kdev-php-23.08.2/parser/php.g" 1
 
 class Lexer;
 
@@ -82,6 +82,14 @@ enum OperationType
     OperationSpaceship,
 };
 
+enum UseImportType
+{
+    NamespaceOrClassImport,
+    ConstantImport,
+    FunctionImport
+};
+
+
 struct KDEVPHPPARSER_EXPORT AstNode
 {
     enum AstNodeKind
@@ -119,108 +127,112 @@ struct KDEVPHPPARSER_EXPORT AstNode
         ClassVariableDeclarationKind = 1030,
         ClosureKind = 1031,
         CommonScalarKind = 1032,
-        CompoundVariableKind = 1033,
-        CompoundVariableWithSimpleIndirectReferenceKind = 1034,
-        ConditionalExpressionKind = 1035,
-        ConstantDeclarationKind = 1036,
-        ConstantOrClassConstKind = 1037,
-        CtorArgumentsKind = 1038,
-        DeclareItemKind = 1039,
-        DeclareStatementKind = 1040,
-        DimListItemKind = 1041,
-        ElseSingleKind = 1042,
-        ElseifListKind = 1043,
-        ElseifListItemKind = 1044,
-        EncapsKind = 1045,
-        EncapsListKind = 1046,
-        EncapsVarKind = 1047,
-        EncapsVarOffsetKind = 1048,
-        EqualityExpressionKind = 1049,
-        EqualityExpressionRestKind = 1050,
-        ExprKind = 1051,
-        ForExprKind = 1052,
-        ForStatementKind = 1053,
-        ForeachStatementKind = 1054,
-        ForeachVariableKind = 1055,
-        FunctionCallKind = 1056,
-        FunctionCallParameterListKind = 1057,
-        FunctionCallParameterListElementKind = 1058,
-        FunctionDeclarationStatementKind = 1059,
-        GenericTypeHintKind = 1060,
-        GlobalVarKind = 1061,
-        IdentifierKind = 1062,
-        IifeSyntaxKind = 1063,
-        InnerStatementListKind = 1064,
-        InstantiationAccessKind = 1065,
-        InterfaceDeclarationStatementKind = 1066,
-        LexicalVarKind = 1067,
-        LexicalVarListKind = 1068,
-        LogicalAndExpressionKind = 1069,
-        LogicalOrExpressionKind = 1070,
-        LogicalXorExpressionKind = 1071,
-        MethodBodyKind = 1072,
-        MultiplicativeExpressionKind = 1073,
-        MultiplicativeExpressionRestKind = 1074,
-        NamespaceDeclarationStatementKind = 1075,
-        NamespacedIdentifierKind = 1076,
-        NewElseSingleKind = 1077,
-        NewElseifListKind = 1078,
-        NewelseifListItemKind = 1079,
-        NullCoalesceExpressionKind = 1080,
-        ObjectDimListKind = 1081,
-        ObjectOperatorKind = 1082,
-        ObjectPropertyKind = 1083,
-        OptionalClassModifierKind = 1084,
-        OptionalModifiersKind = 1085,
-        OuterTopStatementKind = 1086,
-        ParameterKind = 1087,
-        ParameterListKind = 1088,
-        ParameterTypeKind = 1089,
-        PostprefixOperatorKind = 1090,
-        PrintExpressionKind = 1091,
-        PropertyTypeKind = 1092,
-        PropertyTypeHintKind = 1093,
-        RelationalExpressionKind = 1094,
-        RelationalExpressionRestKind = 1095,
-        ReservedNonModifierIdentifierKind = 1096,
-        ReservedNonModifiersKind = 1097,
-        ReturnTypeKind = 1098,
-        ScalarKind = 1099,
-        SemiReservedKind = 1100,
-        SemiReservedIdentifierKind = 1101,
-        SemicolonOrCloseTagKind = 1102,
-        ShiftExpressionKind = 1103,
-        ShiftExpressionRestKind = 1104,
-        StartKind = 1105,
-        StatementKind = 1106,
-        StaticArrayPairValueKind = 1107,
-        StaticMemberKind = 1108,
-        StaticPropertyKind = 1109,
-        StaticScalarKind = 1110,
-        StaticVarKind = 1111,
-        StringIndexSpecifierKind = 1112,
-        SwitchCaseListKind = 1113,
-        TopStatementKind = 1114,
-        TraitAliasDeclarationKind = 1115,
-        TraitAliasIdentifierKind = 1116,
-        TraitAliasStatementKind = 1117,
-        TraitDeclarationStatementKind = 1118,
-        TraitVisibilityModifiersKind = 1119,
-        UnaryExpressionKind = 1120,
-        UnaryExpressionNotPlusminusKind = 1121,
-        UseNamespaceKind = 1122,
-        UseStatementKind = 1123,
-        VarExpressionKind = 1124,
-        VarExpressionArrayKind = 1125,
-        VarExpressionNewObjectKind = 1126,
-        VarExpressionNormalKind = 1127,
-        VariableKind = 1128,
-        VariableIdentifierKind = 1129,
-        VariableNameKind = 1130,
-        VariableObjectPropertyKind = 1131,
-        VariablePropertyKind = 1132,
-        VariableWithoutObjectsKind = 1133,
-        WhileStatementKind = 1134,
+        CompoundNamespaceKind = 1033,
+        CompoundNamespaceStatementKind = 1034,
+        CompoundVariableKind = 1035,
+        CompoundVariableWithSimpleIndirectReferenceKind = 1036,
+        ConditionalExpressionKind = 1037,
+        ConstantDeclarationKind = 1038,
+        ConstantOrClassConstKind = 1039,
+        CtorArgumentsKind = 1040,
+        DeclareItemKind = 1041,
+        DeclareStatementKind = 1042,
+        DimListItemKind = 1043,
+        ElseSingleKind = 1044,
+        ElseifListKind = 1045,
+        ElseifListItemKind = 1046,
+        EncapsKind = 1047,
+        EncapsListKind = 1048,
+        EncapsVarKind = 1049,
+        EncapsVarOffsetKind = 1050,
+        EqualityExpressionKind = 1051,
+        EqualityExpressionRestKind = 1052,
+        ExprKind = 1053,
+        ForExprKind = 1054,
+        ForStatementKind = 1055,
+        ForeachStatementKind = 1056,
+        ForeachVariableKind = 1057,
+        FunctionCallKind = 1058,
+        FunctionCallParameterListKind = 1059,
+        FunctionCallParameterListElementKind = 1060,
+        FunctionDeclarationStatementKind = 1061,
+        GenericTypeHintKind = 1062,
+        GlobalVarKind = 1063,
+        IdentifierKind = 1064,
+        IifeSyntaxKind = 1065,
+        InnerStatementListKind = 1066,
+        InnerUseNamespaceKind = 1067,
+        InstantiationAccessKind = 1068,
+        InterfaceDeclarationStatementKind = 1069,
+        LexicalVarKind = 1070,
+        LexicalVarListKind = 1071,
+        LogicalAndExpressionKind = 1072,
+        LogicalOrExpressionKind = 1073,
+        LogicalXorExpressionKind = 1074,
+        MethodBodyKind = 1075,
+        MultiplicativeExpressionKind = 1076,
+        MultiplicativeExpressionRestKind = 1077,
+        NamespaceDeclarationStatementKind = 1078,
+        NamespacedIdentifierKind = 1079,
+        NamespacedIdentifierBeforeGroupedNamespaceKind = 1080,
+        NewElseSingleKind = 1081,
+        NewElseifListKind = 1082,
+        NewelseifListItemKind = 1083,
+        NullCoalesceExpressionKind = 1084,
+        ObjectDimListKind = 1085,
+        ObjectOperatorKind = 1086,
+        ObjectPropertyKind = 1087,
+        OptionalClassModifierKind = 1088,
+        OptionalModifiersKind = 1089,
+        OuterTopStatementKind = 1090,
+        ParameterKind = 1091,
+        ParameterListKind = 1092,
+        ParameterTypeKind = 1093,
+        PostprefixOperatorKind = 1094,
+        PrintExpressionKind = 1095,
+        PropertyTypeKind = 1096,
+        PropertyTypeHintKind = 1097,
+        RelationalExpressionKind = 1098,
+        RelationalExpressionRestKind = 1099,
+        ReservedNonModifierIdentifierKind = 1100,
+        ReservedNonModifiersKind = 1101,
+        ReturnTypeKind = 1102,
+        ScalarKind = 1103,
+        SemiReservedKind = 1104,
+        SemiReservedIdentifierKind = 1105,
+        SemicolonOrCloseTagKind = 1106,
+        ShiftExpressionKind = 1107,
+        ShiftExpressionRestKind = 1108,
+        StartKind = 1109,
+        StatementKind = 1110,
+        StaticArrayPairValueKind = 1111,
+        StaticMemberKind = 1112,
+        StaticPropertyKind = 1113,
+        StaticScalarKind = 1114,
+        StaticVarKind = 1115,
+        StringIndexSpecifierKind = 1116,
+        SwitchCaseListKind = 1117,
+        TopStatementKind = 1118,
+        TraitAliasDeclarationKind = 1119,
+        TraitAliasIdentifierKind = 1120,
+        TraitAliasStatementKind = 1121,
+        TraitDeclarationStatementKind = 1122,
+        TraitVisibilityModifiersKind = 1123,
+        UnaryExpressionKind = 1124,
+        UnaryExpressionNotPlusminusKind = 1125,
+        UseNamespaceOrUseGroupedNamespaceKind = 1126,
+        UseStatementKind = 1127,
+        VarExpressionKind = 1128,
+        VarExpressionArrayKind = 1129,
+        VarExpressionNewObjectKind = 1130,
+        VarExpressionNormalKind = 1131,
+        VariableKind = 1132,
+        VariableIdentifierKind = 1133,
+        VariableNameKind = 1134,
+        VariableObjectPropertyKind = 1135,
+        VariablePropertyKind = 1136,
+        VariableWithoutObjectsKind = 1137,
+        WhileStatementKind = 1138,
         AST_NODE_KIND_COUNT
     };
 
@@ -228,7 +240,7 @@ struct KDEVPHPPARSER_EXPORT AstNode
     qint64 startToken;
     qint64 endToken;
 
-# 134 "/build/kdevelop-php/src/kdev-php-23.04.3/parser/php.g" 1
+# 141 "/build/kdevelop-php/src/kdev-php-23.08.2/parser/php.g" 1
 
     KDevelop::DUContext* ducontext;
 
@@ -506,6 +518,22 @@ struct KDEVPHPPARSER_EXPORT CommonScalarAst: public AstNode
     StringIndexSpecifierAst *stringIndex;
 };
 
+struct KDEVPHPPARSER_EXPORT CompoundNamespaceAst: public AstNode
+{
+    enum { KIND = CompoundNamespaceKind };
+
+    const KDevPG::ListNode<CompoundNamespaceStatementAst *> *compoundNamespaceStatementSequence;
+};
+
+struct KDEVPHPPARSER_EXPORT CompoundNamespaceStatementAst: public AstNode
+{
+    enum { KIND = CompoundNamespaceStatementKind };
+
+    qint64 useFunction;
+    qint64 useConst;
+    const KDevPG::ListNode<InnerUseNamespaceAst *> *useNamespaceSequence;
+};
+
 struct KDEVPHPPARSER_EXPORT CompoundVariableAst: public AstNode
 {
     enum { KIND = CompoundVariableKind };
@@ -764,6 +792,15 @@ struct KDEVPHPPARSER_EXPORT InnerStatementListAst: public AstNode
     const KDevPG::ListNode<TopStatementAst *> *statementsSequence;
 };
 
+struct KDEVPHPPARSER_EXPORT InnerUseNamespaceAst: public AstNode
+{
+    enum { KIND = InnerUseNamespaceKind };
+
+    UseImportType useImportType;
+    const KDevPG::ListNode<IdentifierAst *> *namespaceNameSequence;
+    IdentifierAst *aliasIdentifier;
+};
+
 struct KDEVPHPPARSER_EXPORT InstantiationAccessAst: public AstNode
 {
     enum { KIND = InstantiationAccessKind };
@@ -855,6 +892,14 @@ struct KDEVPHPPARSER_EXPORT NamespacedIdentifierAst: public AstNode
     const KDevPG::ListNode<IdentifierAst *> *namespaceNameSequence;
 };
 
+struct KDEVPHPPARSER_EXPORT NamespacedIdentifierBeforeGroupedNamespaceAst: public AstNode
+{
+    enum { KIND = NamespacedIdentifierBeforeGroupedNamespaceKind };
+
+    qint64 isGlobal;
+    const KDevPG::ListNode<IdentifierAst *> *namespaceNameSequence;
+};
+
 struct KDEVPHPPARSER_EXPORT NewElseSingleAst: public AstNode
 {
     enum { KIND = NewElseSingleKind };
@@ -1250,12 +1295,14 @@ struct KDEVPHPPARSER_EXPORT UnaryExpressionNotPlusminusAst: public AstNode
     const KDevPG::ListNode<PostprefixOperatorAst *> *postfixOperatorSequence;
 };
 
-struct KDEVPHPPARSER_EXPORT UseNamespaceAst: public AstNode
+struct KDEVPHPPARSER_EXPORT UseNamespaceOrUseGroupedNamespaceAst: public AstNode
 {
-    enum { KIND = UseNamespaceKind };
+    enum { KIND = UseNamespaceOrUseGroupedNamespaceKind };
 
-    NamespacedIdentifierAst *identifier;
+    UseImportType useImportType;
+    NamespacedIdentifierBeforeGroupedNamespaceAst *identifier;
     IdentifierAst *aliasIdentifier;
+    CompoundNamespaceAst *compoundNamespace;
 };
 
 struct KDEVPHPPARSER_EXPORT UseStatementAst: public AstNode
@@ -1264,7 +1311,7 @@ struct KDEVPHPPARSER_EXPORT UseStatementAst: public AstNode
 
     qint64 useFunction;
     qint64 useConst;
-    const KDevPG::ListNode<UseNamespaceAst *> *useNamespaceSequence;
+    const KDevPG::ListNode<UseNamespaceOrUseGroupedNamespaceAst *> *useNamespaceSequence;
 };
 
 struct KDEVPHPPARSER_EXPORT VarExpressionAst: public AstNode
